"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
const fs_1 = require("fs");
const path = require("path");
const child_process_1 = require("child_process");
const semver = require("semver");
const axios_1 = require("axios");
const packageName = "cowlick-export-electron";
const readFilePromise = util_1.promisify(fs_1.readFile);
const execPromise = util_1.promisify(child_process_1.exec);
const npmInstall = "npm install --no-save";
async function bootstrap(baseDir) {
    let pkg;
    try {
        const file = await readFilePromise(path.join(baseDir, `node_modules/${packageName}/package.json`), "utf8");
        pkg = JSON.parse(file);
    }
    catch (e) {
        console.log(`${packageName} is not installed.
${npmInstall} ${packageName}`);
        return execPromise(`${npmInstall} ${packageName}`);
    }
    const response = await axios_1.default.get(`https://registry.npmjs.org/${packageName}/latest`);
    if (response.status === 200) {
        const latest = response.data;
        if (semver.lt(pkg.version, latest.version)) {
            console.log(`found next version.
${npmInstall} ${packageName}@${latest.version}`);
            return execPromise(`${npmInstall} ${packageName}@${latest.version}`);
        }
        else {
            console.log(`${packageName}@${latest.version} is already latest.`);
            return Promise.resolve({});
        }
    }
    else {
        return Promise.reject(response);
    }
}
exports.bootstrap = bootstrap;
